/*
 * Copyright: 2021 UBports
 *
 * This file is part of reminders
 *
 * reminders is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * reminders is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Evernote 0.1

import "../components"

Page {
    id: root

    property int selectedIndex: 0

    header: PageHeader {
        contents: Row {
            anchors.horizontalCenter: parent.horizontalCenter
            height: parent.height
            spacing: units.gu(1)

            ActionIcon {
                id: noteActionIcon
                iconName: "note"
                index: 0
                selectedIndex: root.selectedIndex

                onSelected: {
                    root.selectedIndex = noteActionIcon.index
                    pageBodyLoader.source = Qt.resolvedUrl("NotesPage.qml")
                }
            }

            ActionIcon {
                id: notebookActionIcon
                iconName: "notebook"
                index: 1
                selectedIndex: root.selectedIndex

                onSelected: {
                    root.selectedIndex = notebookActionIcon.index
                    pageBodyLoader.source = Qt.resolvedUrl("NotebooksPage.qml")
                }
            }

            ActionIcon {
                id: tagActionIcon
                iconName: "tag"
                index: 2
                selectedIndex: root.selectedIndex

                onSelected: {
                    root.selectedIndex = tagActionIcon.index
                    pageBodyLoader.source = Qt.resolvedUrl("TagsPage.qml")
                }
            }

            ActionIcon {
                id: reminderActionIcon
                iconName: "reminder"
                index: 3
                selectedIndex: root.selectedIndex

                onSelected: {
                    root.selectedIndex = reminderActionIcon.index
                    pageBodyLoader.source = Qt.resolvedUrl("RemindersPage.qml")
                }
            }
        }
        trailingActionBar.numberOfSlots: 3
        trailingActionBar.actions: [
            Action {
                text: i18n.tr("Add")
                iconName: "add"
                visible: (root.selectedIndex == noteActionIcon.index) ||
                         (root.selectedIndex == notebookActionIcon.index)

                onTriggered: {
                    switch(root.selectedIndex) {
                        case noteActionIcon.index:
                            NotesStore.createNote(i18n.tr("Untitled"))
                            break
                        case notebookActionIcon.index:
                            NotesStore.createNotebook(i18n.tr("Untitled"));
                            break
                        default:
                            console.log("Add not supported for " + root.selectedIndex)
                            break
                    }
                }
            },
            Action {
                text: i18n.tr("Search")
                iconName: "search"

                onTriggered: openSearch()
            },
            Action {
                text: i18n.tr("Settings")
                iconName: "settings"

                onTriggered: pagestack.push(Qt.resolvedUrl("SettingsPage.qml"))
            },
            Action {
                text: i18n.tr("Accounts")
                iconName: "account"

                onTriggered: {
                    var page = pagestack.push(Qt.resolvedUrl("AccountSelectorPage.qml"), { accounts: accounts })

                    page.accountSelected.connect(function(userName, handle) {
                        accountService.startAuthentication(userName, handle)
                        pagestack.pop()
                    })
                }
            },
            Action {
                text: i18n.tr("Help")
                iconName: "help"

                onTriggered: pagestack.push(Qt.resolvedUrl("WelcomePage.qml"))
            }
        ]
    }

    Loader {
        id: pageBodyLoader
        anchors.top: root.header.bottom
        anchors.bottom: root.bottom
        anchors.left: root.left
        anchors.right: root.right
    }

    Component.onCompleted: {
        noteActionIcon.selected()
    }
}
