/*
 * Copyright: 2013 - 2014 Canonical, Ltd
 *
 * This file is part of reminders
 *
 * reminders is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * reminders is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import QtQuick.Layouts 1.1
import QtQuick.Controls.Suru 2.2
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3
import Ubuntu.Components.Popups 1.3
import Evernote 0.1
import "../components"
import Qt.labs.settings 1.0

Item {
    id: root
    objectName: "notesPage"
    anchors.fill: parent

    property var selectedNote: null
    property bool readOnly: false
    property bool narrowMode

    property alias filterNotebookGuid: notes.filterNotebookGuid
    property alias filterTagGuid: notes.filterTagGuid

    signal openSearch()
    signal editNote(var note)

    Settings {
        property alias sortOrder: notes.sortOrder
    }

    Notes {
        id: notes
    }

    function sortOrderToString(sortOrder){
        switch(sortOrder) {
        case Notes.SortOrderDateCreatedNewest:
        case Notes.SortOrderDateCreatedOldest:
            return "createdString";
        case Notes.SortOrderDateUpdatedNewest:
        case Notes.SortOrderDateUpdatedOldest:
            return "updatedString";
        case Notes.SortOrderTitleAscending:
        case Notes.SortOrderTitleDescending:
            return "title";
        }
        return "";
    }

    PulldownListView {
        id: notesListView
        objectName: "notespageListview"
        anchors { left: parent.left; right: parent.right }
        height: parent.height - y
        model: notes
        clip: true
        maximumFlickVelocity: units.gu(200)

        onRefreshed: {
            NotesStore.refreshNotes();
        }

        delegate: NoteDelegate {
            objectName: "noteDelegate" + index
            note: model

            Component.onCompleted: {
                notes.note(model.guid).load(false);
            }

            onOpenNote: {
                root.selectedNote = NotesStore.note(guid)
                displayNote(root.selectedNote, !root.selectedNote.conflicting)
            }
            onDeleteNote: {
                var confirmation = PopupUtils.open(Qt.resolvedUrl("../components/DeleteConfirmationDialog.qml"),
                                                   root,
                                                   { targetType: i18n.tr("note"), targetTitle: model.title })
                confirmation.confirmed.connect(function() { NotesStore.deleteNote(model.guid) })
            }
            onEditNote: {
                //root.editNote(NotesStore.note(model.guid));
                switchToEditMode(NotesStore.note(model.guid))
            }
            onEditReminder: {
                pageStack.push(Qt.resolvedUrl("SetReminderPage.qml"), { note: NotesStore.note(model.guid) });
            }
            onEditTags: {
                var popup = PopupUtils.open(Qt.resolvedUrl("../components/EditTagsDialog.qml"), root,
                                { note: NotesStore.note(model.guid) })
                popup.done.connect(function() { NotesStore.saveNote(popup.note.guid)})
            }
        }

        section.criteria: {
            switch (notes.sortOrder) {
            case Notes.SortOrderTitleAscending:
            case Notes.SortOrderTitleDescending:
                return ViewSection.FirstCharacter;
            }

            return ViewSection.FullString
        }
        section.property: root.sortOrderToString(notes.sortOrder);

        section.delegate: ListItem {
            height: units.gu(5)
            Rectangle {
                anchors { left: parent.left; top: parent.top; right: parent.right }
                height: units.dp(1)
                color: Suru.neutralColor
                //visible: index > 0
            }

            RowLayout {
                anchors { left: parent.left; right: parent.right; verticalCenter: parent.verticalCenter; margins: units.gu(1) }
                Label {
                    text: section
                    Layout.fillWidth: true
                }
                Label {
                    text: "(" + notes.sectionCount(root.sortOrderToString(notes.sortOrder), section) + ")"
                }
            }
        }

        BouncingProgressBar {
            anchors.top: parent.top
            visible: notes.loading
        }
        Label {
            anchors.centerIn: parent
            visible: !notes.loading && notesListView.count == 0
            width: parent.width - units.gu(4)
            wrapMode: Text.WordWrap
            horizontalAlignment: Text.AlignHCenter
            text: i18n.tr("No notes available. You can create new notes by pressing + in the top right menu.")
        }

        Scrollbar {
            flickableItem: parent
        }
    }
}
