/*
 * Copyright: 2013 - 2014 Canonical, Ltd
 *
 * This file is part of reminders
 *
 * reminders is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * reminders is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.4
import Ubuntu.Components 1.3
import Ubuntu.Components.ListItems 1.3
import Ubuntu.Components.Popups 1.3
import Evernote 0.1

import "../components"

Item {
    id: root
    objectName: "tagsPage"
    anchors.fill: parent

    signal openTaggedNotes(string tagGuid)

    Tags {
        id: tags
    }

    UbuntuListView {
        id: tagsListView
        anchors.fill: parent
        pullToRefresh.enabled: preferences.accountName != "@local"
        pullToRefresh.refreshing: tags.loading
        pullToRefresh.onRefresh: tags.refresh()
        currentIndex: -1 // Workaround: UbuntuListView seems to auto-highlight the 1st item
        clip: true
        model: tags
        delegate: TagDelegate {
            width: parent.width
            height: units.gu(8)
            tag: model

            onOpenTag: {
                //root.openTaggedNotes(model.guid)
                var page = pagestack.push(Qt.resolvedUrl("FilteredNotesPage.qml"),
                                          { title: model.name, filterTagGuid: model.guid, narrowMode: narrowMode });
            }
            onDeleteTag: {
                var confirmation = PopupUtils.open(Qt.resolvedUrl("../components/DeleteConfirmationDialog.qml"),
                                                   root,
                                                   { targetType: i18n.tr("tag"), targetTitle: model.name })
                confirmation.confirmed.connect(function() { NotesStore.expungeTag(model.guid) })
            }
            onRenameTag: {
                var popup = PopupUtils.open(renameTagDialogComponent, root, { name: model.name })
                popup.accepted.connect(function(newName) {
                    tags.tag(index).name = newName
                    NotesStore.saveTag(model.guid)
                })
            }
        }
    }

    Label {
        anchors.centerIn: parent
        visible: !tags.loading && tagsListView.count == 0
        width: parent.width - units.gu(4)
        wrapMode: Text.WordWrap
        horizontalAlignment: Text.AlignHCenter
        text: i18n.tr("No tags available. You can tag notes while viewing them.")
    }

    Component {
        id: renameTagDialogComponent

        Dialog {
            id: renameTagDialog
            title: i18n.tr("Rename tag")

            property string name

            signal accepted(string newName)

            TextField {
                id: nameTextField
                text: renameTagDialog.name
                placeholderText: i18n.tr("Name cannot be empty")
            }

            Button {
                text: i18n.tr("Rename")
                color: theme.palette.normal.positive
                enabled: nameTextField.displayText.trim()

                onClicked: {
                    renameTagDialog.accepted(nameTextField.text)
                    PopupUtils.close(renameTagDialog)
                }
            }

            Button {
                text: i18n.tr("Cancel")

                onClicked: {
                    PopupUtils.close(renameTagDialog)
                }
            }
        }
    }
}
